<div align="center">

<img src="https://raw.githubusercontent.com/joeyagreco/pymfl/main/img/mfl_logo.png" alt="sleeper logo" width="250"/>

Python wrapper for the MyFantasyLeague API.

[MyFantasyLeague Website](http://home.myfantasyleague.com/)\
[MyFantasyLeague API Documentation](https://api.myfantasyleague.com/2022/api_info)

![Last Commit](https://img.shields.io/github/last-commit/joeyagreco/pymfl)
</div>

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```bash
pip install pymfl
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)